jk-js
=====

jk-js is a small JavaScript library providing utility functions.

[Click here for a live example.](http://josuakrause.github.io/jk-js/)

TODO write project description

TODO packages:
  * (pos)
  * (handling byte array bit sets)
  * defer calls
  * animation
  * search
  * io
